@@ -146,7 +146,7 @@ class CLI:
         - service/worker: identifiers reported to eigenpuls
         - url: eigenpuls base URL
         - host/port/path: probe target (path only for http)
-        - apikey_env: environment variable name to read bearer token from
+        - apikey_env_var: environment variable name to read bearer token from
         """
         probe = probe.lower().strip()
         allowed = {"postgres", "redis", "rabbitmq", "http", "tcp"}
@@ -155,10 +155,10 @@ class CLI:
         
         if not url:
             raise ValueError("url is required")
-            
+
         base_url = url
         from importlib.resources import files as _files
-        script_path = _files("eigenpuls.eigenpuls.resources").joinpath(self.client_script_name())
+        script_path = _files("eigenpuls.resources").joinpath(self.client_script_name())
         envs = [
             "ACTION=probe",
             f"PROBE={probe}",
